#
# spec file for package pesign
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pesign
Version:        0.112
Release:        150000.4.12.1
Summary:        Signing tool for PE-COFF binaries
License:        GPL-2.0-only
Group:          Productivity/Security
Url:            https://github.com/rhinstaller/pesign
Source:         https://github.com/rhinstaller/pesign/releases/download/%{version}/%{name}-%{version}.tar.bz2
# PATCH-FIX-SUSE pesign-suse-build.patch glin@suse.com -- Adjust Makefile for the build service
Patch1:         pesign-suse-build.patch
# PATCH-FIX-UPSTREAM pesign-fix-build-errors.patch glin@suse.com -- Fix gcc warnings
Patch2:         pesign-fix-build-errors.patch
# PATCH-FIX-UPSTREAM pesign-privkey_unneeded.diff glin@suse.com -- Don't check the private key when importing the raw signature
Patch3:         pesign-privkey_unneeded.diff
# PATCH-FIX-SUSE pesign-run.patch aj@suse.com - Use /run instead of /var/run
Patch5:         pesign-run.patch
# PATCH-FIX-UPSTREAM pesign-fix-authvar-write-loop.patch glin@suse.com -- Fix the write loop in authvar
Patch6:         pesign-fix-authvar-write-loop.patch
# PATCH-FIX-UPSTREAM pesign-fix-argument-list.patch glin@suse.com -- Fix the argument list parsing
Patch7:         pesign-fix-argument-list.patch
# PATCH-FIX-UPSTREAM bsc#1087742 pesign-bsc1087742-fix-efisiglist.patch glin@suse.com -- Fix efi signature list generation
Patch8:         pesign-bsc1087742-fix-efisiglist.patch
# PATCH-FIX-UPSTREAM bsc#1144441 pesign-bsc1144441-efikeygen-Fix-the-build-with-nss-3.44.patch glin@suse.com -- Fix the build failure with nss 3.44
Patch9:         pesign-bsc1144441-efikeygen-Fix-the-build-with-nss-3.44.patch
# PATCH-FIX-UPSTREAM bsc#1205323 pesign-bsc1205323-add-shim-eku-oid-and-fix-array-indices.patch glin@suse.com -- Add the shim EKU OID and fix the OID array indices
Patch10:        pesign-bsc1205323-add-shim-eku-oid-and-fix-array-indices.patch
BuildRequires:  efivar-devel
BuildRequires:  libuuid-devel
BuildRequires:  mozilla-nss-devel
BuildRequires:  pkg-config
BuildRequires:  popt-devel
BuildRequires:  pkgconfig(systemd)
Requires(pre):  shadow
%{?systemd_requires}
ExclusiveArch:  ia64 %ix86 x86_64 aarch64 %arm

%description
Signing tool for PE-COFF binaries, hopefully at least vaguely compliant
with the PE and Authenticode specifications.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1

%build
make %{?_smp_mflags} CFLAGS="$RPM_OPT_FLAGS" LDFLAGS="$LDFLAGS -pie"

%install
make INSTALLROOT=%{buildroot} libexecdir=%{_libexecdir} install
mkdir -p %{buildroot}%{_localstatedir}/lib/pesign

mkdir -p %{buildroot}%{_sbindir}
make INSTALLROOT=%{buildroot} UNITDIR=%{_unitdir} libexecdir=%{_libexecdir} install_systemd

# create rcsymlink
ln -sv %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

# there's some stuff that's not really meant to be shipped yet
rm -rf %{buildroot}/boot %{buildroot}%{_prefix}/include
rm -rf %{buildroot}%{_libdir}/libdpe*

%pre
getent group pesign >/dev/null || groupadd -r pesign
getent passwd pesign >/dev/null || useradd -r -g pesign -d %{_localstatedir}/lib/pesign -s /bin/false -c "PE-COFF signing daemon" pesign
%service_add_pre pesign.service

%preun
%service_del_preun pesign.service

%post
%service_add_post pesign.service
systemd-tmpfiles --create %{_libexecdir}/tmpfiles.d/pesign.conf || :

%postun
%service_del_postun pesign.service

%files
%defattr(-,root,root)
%license COPYING
%{_bindir}/pesign
%{_bindir}/pesign-client
%{_bindir}/efikeygen
%{_bindir}/pesigcheck
%{_bindir}/efisiglist
%{_bindir}/authvar
%{_sbindir}/rcpesign
%dir %{_sysconfdir}/pesign
%{_sysconfdir}/pesign/*
%dir %{_sysconfdir}/popt.d
%config %{_sysconfdir}/popt.d/pesign.popt
%{_sysconfdir}/pki/
%config %{_sysconfdir}/rpm/macros.pesign
%{_mandir}/man?/*
%{_localstatedir}/lib/pesign
%{_unitdir}/pesign.service
%{_libexecdir}/tmpfiles.d/pesign.conf
%dir %{_libexecdir}/pesign
%{_libexecdir}/pesign/pesign-authorize-*
%dir %attr(0775,pesign,pesign) %{_sysconfdir}/pki/pesign
%ghost %dir %attr(0770,pesign,pesign) /run/%{name}
%dir %attr(0770,pesign,pesign) %{_localstatedir}/lib/%{name}

%changelog
* Mon Nov 14 2022 glin@suse.com
- Add pesign-bsc1205323-add-shim-eku-oid-and-fix-array-indices.patch
  to add shim EKU OID and fix OID array indices (bsc#1205323)
* Tue Jun  8 2021 wolfgang.frisch@suse.com
- Link as Position Independent Executable (bsc#1184124).
* Tue Aug  6 2019 glin@suse.com
- Add pesign-bsc1144441-efikeygen-Fix-the-build-with-nss-3.44.patch
  to fix the build failure with nss 3.44 (bsc#1144441)
* Thu May  9 2019 guillaume.gardet@opensuse.org
- Enable build on %%arm as we can sign kernel on %%arm (boo#1134670)
* Fri Apr 26 2019 mvetter@suse.com
- bsc#1130588: Require shadow instead of old pwdutils
* Mon Apr  2 2018 glin@suse.com
- Add pesign-bsc1087742-fix-efisiglist.patch to fix the generation
  of efi signature list. (bsc#1087742)
* Thu Aug 11 2016 glin@suse.com
- Add pesign-fix-argument-list.patch to fix the argument list
  parsing
* Thu Apr 21 2016 glin@suse.com
- Update to 0.112
- Refresh patches: pesign-suse-build.patch and pesign-run.patch
- Drop upstreamed pesign-fix-signness.patch
* Tue Nov 10 2015 glin@suse.com
- Update to 0.111
- Add pesign-fix-signness.patch to fix the signness comparison
- Drop upstreamed patches
  + pesign-efivar-pkgconfig.patch
  + pesign-make-efi_guid_t-const.patch
  + pesign-fix-import-sig-check.patch
  + pesign-install-supplementary-programs.patch
- Refresh pesign-suse-build.patch, pesign-privkey_unneeded.diff,
  and pesign-run.patch
- Update pesign-fix-build-errors.patch
- Merge use-standard-pid-location.patch into pesign-run.patch
* Tue Sep  1 2015 dimstar@opensuse.org
- Do not buildrequire systemd: it conflicts with systemd-mini,
  which is pulled in by systemd-mini-devel (due to BuildRequires:
  pkgconfig(systemd).
- As we lack systemd-tmpfiles in the build env, we ignore the
  errors cast in the %%post scriptlet.
* Fri Aug 14 2015 mpluskal@suse.com
- Update project url
- Use url for download
- Add rcpesign symlink
- Tiny spec file cleanup with spec-cleaner
* Mon Jul 13 2015 werner@suse.de
- Make it build, tool systemd-tmpfiles is part of systemd
* Tue Jun 16 2015 glin@suse.com
- Add pesign-efivar-pkgconfig.patch to get the efivar compiler
  parameters from pkg-confg
- Add pesign-make-efi_guid_t-const.patch to avoid the error from
  gcc
* Wed Nov 26 2014 glin@suse.com
- Add pesign-fix-import-sig-check.patch to fix the signature size
  check while importing a signature
- Amend the spec file with spec-cleaner
* Fri Oct 31 2014 glin@suse.com
- Update pesign-suse-build.patch to set LIBDIR for AArch64
* Tue Oct 28 2014 glin@suse.com
- Update to version 0.110
- Add pesign-fix-authvar-write-loop.patch to fix the write loop in
  authvar
- Add pesign-install-supplementary-programs.patch to install the
  supplementary programs
- Refresh patches
  + pesign-fix-build-errors.patch
  + pesign-run.patch
  + pesign-suse-build.patch
- Drop upstreamed patches
  + pesign-clear-padding-bits.patch
  + pesign-enable-supplementary-programs.patch
  + pesign-no-db.patch
- Enable aarch64
* Tue Jul  1 2014 glin@suse.com
- Update pesign-enable-supplementary-programs.patch to fix write
  loop
* Thu Jun 12 2014 glin@suse.com
- Add pesign-enable-supplementary-programs.patch to fix and enable
  the supplementary programs: pesigcheck, authvar, efisiglist
* Wed Apr 16 2014 aj@suse.com
- Add pesign-run.patch: Use /run instead of /var/run (bnc#873857).
* Fri Jan 31 2014 lnussel@suse.de
- mark dir in /var/run as %%ghost
* Thu Nov  7 2013 glin@suse.com
- Add pesign-no-db.patch to allow some commands to proceed without
  a NSS database.
* Thu Oct 24 2013 glin@suse.com
- Revert the dowload Url since it's not valid
* Tue Oct 22 2013 p.drouand@gmail.com
- Update to version 0.109
- Remove sysvinit related old stuff
- Remove redundant %%clean section
- Add use-standard-pid-location.patch
  Use the good location to stock pidfile
- Use download Url as source
- Rebase pesign-suse-build.patch to upstream changes as it has been
  partially merged on upstream
- Remove pesign-allow-no-issuer-cert.patch; fixed on upstream
* Thu Jul 18 2013 glin@suse.com
- Add pesign-allow-no-issuer-cert.patch to avoid crash when the
  issuer's certificate is not available
* Tue Jul  9 2013 glin@suse.com
- Update to 0.106
- Add pesign-clear-padding-bits.patch to clear the padding bits
- Rebase patches:
  + pesign-suse-build.patch
  + pesign-fix-build-errors.patch
  + pesign-privkey_unneeded.diff
- Drop upstreamed patches
  + pesign-client-initialize-action.patch
  + pesign-bnc808594-align-signatures.patch
  + pesign-upstream-fixes.patch
  + pesign-fix-export-attributes.patch
  + pesign-no-set-image-size.patch
  + pesign-client-read-pin-file.patch
  + pesign-local-database.patch
  + pesign-bnc801653-teardown-segfault.patch
  + pesign-bnc805166-fix-signature-list.patch
* Tue Mar 26 2013 glin@suse.com
- Add pesign-bnc808594-align-signatures.patch to align signatures
  (bnc#808594, bnc#811325)
* Fri Mar  1 2013 glin@suse.com
- Update pesign-bnc805166-fix-signature-list.patch to avoid the
  potential crash when inserting a signature (bnc#805166)
- Add pwdutils to PreReq
* Mon Feb 25 2013 glin@suse.com
- Update pesign-bnc805166-fix-signature-list.patch to skip the
  unneeded private key request. (bnc#805166c#17)
* Sat Feb 23 2013 jlee@suse.com
- Modified pesign-bnc805166-fix-signature-list.patch, block out the
  source code for find/attach Issuer certificate
  (bnc#805166 comment#13)
* Fri Feb 22 2013 glin@suse.com
- Add pesign-bnc805166-fix-signature-list.patch to fix the broken
  signature list when inserting signature into a signed EFI binary
  (bnc#805166)
* Tue Feb 12 2013 mls@suse.de
- do not try to recalculate the image size, it is included in the
  hash and therefore must not change.
* Wed Feb  6 2013 glin@suse.com
- Merge patches for FATE#314552
  + pesign-fix-export-attributes.patch: fix crash when exporting
    the signed attributes
  + pesign-privkey_unneeded.diff: Don't check the private key when
    importing the raw signature
- Add pesign-bnc801653-teardown-segfault.patch to fix crash when
  freeing digests (bnc801653)
- Drop pesign-digestdata.diff which is no longer needed.
* Mon Jan 21 2013 glin@suse.com
- Add pesign-digestdata.diff to generate digestdata (FATE#314552)
* Wed Dec 12 2012 fcrozat@suse.com
- Don't call sysv RPM post/pre macros when building for systemd
- Ship rcpesign for systemd, link to /sbin/service
- Update pesign-suse-build.patch to allow change systemd unit
  install directory.
- Don't hardcode systemd unit directory, since it changed in
  Factory.
* Tue Dec 11 2012 glin@suse.com
- Add Requires: pwdutils
* Wed Nov 28 2012 glin@suse.com
- Add pesign-local-database.patch to support the local certificate
  database
- Amend the spec file to build on openSUSE:Factory
* Thu Nov  8 2012 glin@suse.com
- Version bump to 0.99 (FATE#314484)
  + Add documentation for --daemonize and --nofork
  + Make popt aliases work
  + Add documentation for pesign-client
  + Add --pinfd and --pinfile to the client
- Update pesign-suse-build.patch and pesign-fix-build-errors.patch
- Add pesign-upstream-fixes.patch to backport fixes from git head
  and add sysvinit script
- Add pesign-client-initialize-action.patch to initialize client
  action to avoid undetermined flags.
- Add pesign-client-read-pin-file.patch to fix pin file reading
* Mon Oct 15 2012 glin@suse.com
- Version bump to 0.98
  + close the socket immediately on invalid input
  + Slightly better error messages
  + Log an error if digest initialization fails
  + Add systemd bits for pesignd
  + Add actual signing code to the daemon
  + Add input and output setup for sign functionality in the daemon
  + Audit allocation of CERTCertificateList/PK11SlotList and
    friends
  + Fix memory leaks
- Refresh pesign-suse-build.patch and pesign-fix-build-errors.patch
* Mon Aug 13 2012 glin@suse.com
- Version bump to 0.9
  + Add NSS "token" support for smartcards.
  + Allocate space for the section header variable
- Refresh pesign-fix-build-errors.patch to fix the warning
- Drop upstreamed pesign-allocate-shdr.patch
* Fri Aug 10 2012 glin@suse.com
- Add pesign-allocate-shdr.patch to allocate space for the section
  header variable
* Thu Aug  9 2012 glin@suse.com
- Version bump to 0.8
  + Don't open the DB r/w, read-only is fine.
  + Attempt to do a better job setting the image size.
  + Emit correct OID for encryption type.
- Drop pesign-fix-image-size.patch which is already in 0.8
* Tue Aug  7 2012 glin@suse.com
- Add upstream patch pesign-fix-image-size.patch to set the image
  size correctly.
- Drop pesign-elilo-workaround.patch
* Mon Aug  6 2012 glin@suse.com
- Version bump to 0.7
  + Fix incorrect initialization error in (undocumented) -e option.
  + Use SEC_OID_PKCS1_RSA_ENCRYPTION like MS
  + Initialize the index variable of loop
  + Adjust the buffer size to avoid overflow
  + Make sure pe_populatecert() always returns a value
* Mon Jul 23 2012 glin@suse.com
- Add pesign-elilo-workaround.patch to workaround the section
  header corruption in some EFI image (elilo for example)
* Mon Jul 23 2012 glin@suse.com
- Add pesign-fix-build-errors.patch to fix build error/warning
- Don't install the util efi images
- Fix the RPM_OPT_FLAGS warning
* Thu Jul 12 2012 glin@suse.com
- Version bump to 0.5
  + Handle and report mremap() failure
  + Man page should be in section 1.
  + Add some basic signature list management.
  + Add some more efi-defined constants, flesh out efi_guid_t.
  + authver: Find a guid for 'namespace'.
  + Add some basic ucs2 functions :(
  + Support multiple signatures correctly.
  + Add ascii_to_ucs2()
  + Add file formats and some code for variables-on-disk.
  + Allow the memory map to move when we're allocating space in the
    binary.
  + Remove extra call to ftruncate()
  + Adjust section addresses when we remap the pecoff binary.
  + Correctly set win_certificate.length to /include/
    win_certificate.
  + Move certificate space iterator to wincert.c so other stuff can
    get it.
  + Split allocating space for certs and filling it in.
  + Put the new signature into the cms ctx instead of keeping it
    locally.
  + Actually calculate space and extend the file before hashing the
    binary.
  + Bounds-check everything we're hashing so we don't segfault on a
    bad bin.
- Add pesign-always-return-value.patch to fix
  no-return-in-nonvoid-function
- Drop upsreamed patch pesign-mem-reallocation.patch
* Fri Jun 29 2012 glin@suse.com
- Add pesign-mem-reallocation.patch to fix crash when writing
  signature
* Tue Jun 26 2012 glin@suse.com
- Version bump to 0.3
  + it seems to generate working signatures
* Thu Jun 21 2012 glin@suse.com
- New package pesign 0.2
